@@ -186,12 +186,12 @@ GtkWidget*	basep_widget_construct		(gchar *panel_id,
 						 BasePState state,
 						 gboolean hidebuttons_enabled,
 						 gboolean hidebutton_pixmaps_enabled,
-						 PanelBackType back_type,
+						 PanelBackgroundType back_type,
 						 char *back_pixmap,
 						 gboolean fit_pixmap_bg,
 						 gboolean stretch_pixmap_bg,
 						 gboolean rotate_pixmap_bg,
-						 GdkColor *back_color);
+						 PanelColor *back_color);
 
 /* changing parameters */
 void		basep_widget_change_params	(BasePWidget *basep,
@@ -203,12 +203,12 @@ void		basep_widget_change_params	(BasePWidget *basep,
 						 BasePState state,
 						 gboolean hidebuttons_enabled,
 						 gboolean hidebutton_pixmaps_enabled,
-						 PanelBackType back_type,
+						 PanelBackgroundType back_type,
 						 char *pixmap_name,
 						 gboolean fit_pixmap_bg,
 						 gboolean stretch_pixmap_bg,
 						 gboolean rotate_pixmap_bg,
-						 GdkColor *back_color);
+						 PanelColor *back_color);
 
 void            basep_widget_screen_size_changed (BasePWidget *basep,
 						  GdkScreen   *screen);
