@@ -62,8 +62,7 @@ properties_apply_callback(gpointer data)
 							    "panel-drawer.png", TRUE, NULL);
 	}
 
-	button_widget_set_pixmap (BUTTON_WIDGET (drawer->button),
-				  drawer->pixmap, -1);
+	button_widget_set_pixmap (BUTTON_WIDGET (drawer->button), drawer->pixmap);
 
 	cs = gtk_entry_get_text(GTK_ENTRY(gnome_entry_gtk_entry(GNOME_ENTRY(tipentry))));
 	if (string_empty (cs))
@@ -315,7 +314,7 @@ key_press_drawer (GtkWidget *widget, GdkEventKey *event, gpointer data)
 	GtkWidget *drawer_panel;
 	GtkDirectionType dir;
 
-	if (event->state == 0) {
+	if (event->state != gtk_accelerator_get_default_mod_mask ()) {
 		drawer = data;
 		parent = PANEL_WIDGET (drawer->button->parent);
 		drawerw = DRAWER_WIDGET (drawer->drawer);
@@ -397,7 +396,7 @@ key_press_drawer_widget (GtkWidget *widget, GdkEventKey *event, gpointer data)
 		if (event->state == GDK_SHIFT_MASK) {
 			gtk_window_present (GTK_WINDOW (parent->panel_parent));
 			ret_val = TRUE;
-		} else if (event->state == 0) {
+		} else if (event->state != gtk_accelerator_get_default_mod_mask ()) {
 			gtk_window_present (GTK_WINDOW (parent->panel_parent));
 			switch (BASEP_WIDGET (drawerw)->state) {
 			case BASEP_SHOWN:
@@ -475,8 +474,7 @@ create_drawer_applet (GtkWidget   *drawer_panel,
 		drawer->pixmap = g_strdup (pixmap);
 	}
 	drawer->button = button_widget_new (drawer->pixmap, -1,
-					    TRUE, orient,
-					    _("Drawer"));
+					    TRUE, orient);
 	if (!drawer->button) {
 		free_drawer (drawer);
 		return NULL;
@@ -528,17 +526,28 @@ create_drawer_applet (GtkWidget   *drawer_panel,
 }
 
 static Drawer *
-create_empty_drawer_applet(const char *tooltip, const char *pixmap,
-			   PanelOrient orient)
+create_empty_drawer_applet (PanelWidget *container,
+			    const char  *tooltip,
+			    const char  *pixmap,
+			    PanelOrient  orient)
 {
-	GtkWidget *dw = drawer_widget_new (NULL, orient,
+	GtkWidget *drawer_widget;
+	int        screen;
+	int        monitor;
+
+	screen  = panel_screen_from_panel_widget (container);
+	monitor = panel_monitor_from_panel_widget (container);
+
+	drawer_widget = drawer_widget_new (NULL, screen,
+					   monitor, orient,
 					   BASEP_EXPLICIT_HIDE,
 					   BASEP_SHOWN,
 					   PANEL_SIZE_MEDIUM,
 					   TRUE, TRUE,
 					   PANEL_BACK_NONE, NULL,
 					   TRUE, FALSE, TRUE, NULL);
-	return create_drawer_applet (dw, tooltip, pixmap, orient);
+	return create_drawer_applet (
+			drawer_widget, tooltip, pixmap, orient);
 }
 
 void
@@ -596,7 +605,7 @@ load_drawer_applet (gchar       *mypanel_id,
 	orient = panel_widget_get_applet_orient (panel);
 
 	if (!mypanel_id) {
-		drawer = create_empty_drawer_applet (tooltip, pixmap, orient);
+		drawer = create_empty_drawer_applet (panel, tooltip, pixmap, orient);
 		if (drawer != NULL)
 			panel_setup (drawer->drawer);
 		panels_to_sync = TRUE;
@@ -607,12 +616,12 @@ load_drawer_applet (gchar       *mypanel_id,
 
 		if (dr_pd == NULL) {
 			g_warning ("Can't find the panel for drawer, making a new panel");
-			drawer = create_empty_drawer_applet(tooltip, pixmap, orient);
+			drawer = create_empty_drawer_applet(panel, tooltip, pixmap, orient);
 			if(drawer) panel_setup(drawer->drawer);
 			panels_to_sync = TRUE;
 		} else if ( ! DRAWER_IS_WIDGET (dr_pd->panel)) {
 			g_warning ("I found a bogus panel for a drawer, making a new one");
-			drawer = create_empty_drawer_applet(tooltip, pixmap, orient);
+			drawer = create_empty_drawer_applet(panel, tooltip, pixmap, orient);
 			if(drawer) panel_setup(drawer->drawer);
 			panels_to_sync = TRUE;
 		} else {
